/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */

package org.apache.rat.walker;

import org.apache.rat.api.Document;
import org.apache.rat.document.DocumentName;
import org.apache.rat.report.IReportable;

/**
 * Abstract walker.
 */
public abstract class Walker implements IReportable {

    /** The document this walker is walking */
    private final Document document;

    /**
     * Creates the walker
     * @param document The document the walker is walking.
     */
    protected Walker(final Document document) {
        this.document = document;
    }

    /**
     * Retrieves the document from the constructor.
     * @return the document from the constructor.
     */
    protected Document getDocument() {
        return document;
    }

    @Override
    public DocumentName getName() {
        return document.getName();
    }
}
